@@ -102,20 +102,20 @@ const (
 )
 
 func (s *scm) RelativeDir() string {
-	if len(s.Dir) == 0 {
+	if s.repoRootDir == "" {
 		return ""
 	}
 
 	pwd := s.env.Pwd()
-	log.Debug("scm.Dir:", s.Dir, "pwd:", pwd)
+	log.Debug("repo root dir:", s.repoRootDir, "pwd:", pwd)
 
-	rel, err := filepath.Rel(s.Dir, pwd)
+	rel, err := filepath.Rel(s.repoRootDir, pwd)
 	if err != nil {
 		log.Error(err)
 	}
 
-	if rel == "." || len(rel) == 0 {
-		log.Debug("scm.Dir is the same as the current working directory, returning empty string")
+	if rel == "." || rel == "" {
+		log.Debug("repo root dir is the same as the current working directory, returning empty string")
 		return ""
 	}
 
@@ -157,7 +157,7 @@ func (s *scm) formatBranch(branch string) string {
 	}
 
 	branchTemplate := s.props.GetString(BranchTemplate, "")
-	if len(branchTemplate) == 0 {
+	if branchTemplate == "" {
 		return branch
 	}
 
